@@ -1,4 +1,4 @@
-REVAPI <- "http://test.geodata.nationaalgeoregister.nl/locatieserver/revgeo"
+REVAPI <- "http://https://api.pdok.nl/bzk/locatieserver/search/v3_1/reverse/"
 
 #' experimental reverse api
 nl_reverse <- function(){
